| Title: | Generate dummy text |
|---|---|
| Description: | Functions that generate dummy text. This is useful when developping a corporate identity for documents. |
| Authors: | Thierry Onkelinx [aut, cre] (ORCID: <https://orcid.org/0000-0001-8804-4216>), Research Institute for Nature and Forest [cph, fnd] |
| Maintainer: | Thierry Onkelinx <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-11 06:36:11 UTC |
| Source: | https://github.com/inbo/lipsum |
A data frame with sentences from the lipsum corpuse
A data frame with 3189 rows and 4 variables:
an integer id of the paragraph
the number of characters in the sentence
the number of words in the sentence
the actual sentence
return lipsum paragraphs
paragraph(id, words, characters, n = 1)paragraph(id, words, characters, n = 1)
id |
the id of the paragraph |
words |
an optional prefered number of words. Only used when |
characters |
an optional prefered number of characters. Only used when |
n |
the number of random paragraphs. Only used when |
an string of paragraphs. The paragraphs are separated by a double newline character.
paragraph() paragraph(n = 2) paragraph(10) paragraph(c(7, 1)) paragraph(words = 12, n = 2) paragraph(characters = 90)paragraph() paragraph(n = 2) paragraph(10) paragraph(c(7, 1)) paragraph(words = 12, n = 2) paragraph(characters = 90)
A single paragraph with the sentences will be displayed
sentence(id, n = 1, words, characters)sentence(id, n = 1, words, characters)
id |
the number of the sentence |
n |
the number of random sentences. Only used when |
words |
an optional prefered number of words. Only used when |
characters |
an optional prefered number of characters. Only used when |
a string of sentences
sentence() sentence(1) sentence(2:3) sentence(words = 5)sentence() sentence(1) sentence(2:3) sentence(words = 5)